JustAnalyticsNavigationObserver class

A NavigatorObserver that creates spans for screen transitions.

Each route push creates a screen.view span with the route name. Pop, replace, and remove events are recorded as span events on the current screen span.

Inheritance

Constructors

JustAnalyticsNavigationObserver({required SpanSink spanSink, required String serviceName, ActiveTraceProvider? traceProvider})
Creates a new JustAnalyticsNavigationObserver.

Properties

currentScreenSpan Span?
The currently active screen span (visible for testing).
no setter
hashCode int
The hash code for this object.
no setterinherited
The navigator that the observer is observing, if any.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
override
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
override
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
override
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
override
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited